@@ -3,7 +3,7 @@ import os
 import platform
 
 from e2e_cli.core.py_manager import Py_version_manager
-from e2e_cli.core.alias_service import check_user_cred
+from e2e_cli.core.alias_service import get_user_cred
 from e2e_cli.config.config_service import is_valid
 
 class AuthConfig:
@@ -17,9 +17,13 @@ class AuthConfig:
             self.folder= self.home_directory + "/.E2E_CLI"
             self.file= self.home_directory + "/.E2E_CLI/config.json"
 
+
     def windows_hider(self):
         os.system("attrib +h " + self.folder)
-        
+
+    def macOS_hider(self):
+        os.system("chflags hidden" + self.folder)
+
     def windows_file_check(self):
         if not os.path.isdir(self.folder):
             return -1
@@ -30,7 +34,17 @@ class AuthConfig:
             self.windows_hider()
             return 1
 
-    def linux_mac_file_check(self):
+    def macOS_file_check(self):
+        if not os.path.isdir(self.folder):
+            return -1
+        elif not os.path.isfile(self.file):
+            self.macOS_hider()
+            return 0
+        else:
+            self.macOS_hider()
+            return 1
+
+    def linux_file_check(self):
         if not os.path.isdir(self.folder):
             return -1
         elif not os.path.isfile(self.file):
@@ -41,8 +55,10 @@ class AuthConfig:
     def check_if_file_exist(self):
         if platform.system() == "Windows":
             return self.windows_file_check()
-        elif platform.system() == "Linux" or platform.system() == "Mac":
-            return self.linux_mac_file_check()
+        elif platform.system() == "Linux":
+            return self.linux_file_check()
+        elif platform.system() == "Mac":
+            return self.macOS_file_check()
 
     def add_json_to_file(self):
         api_access_credentials_object = {"api_key": self.kwargs["api_key"],
@@ -78,7 +94,7 @@ class AuthConfig:
                 pass
             self.add_json_to_file()
         elif file_exist_check_variable == 1:
-            if (check_user_cred(self.kwargs['alias'])):
+            if (get_user_cred(self.kwargs['alias'],2)):
                 Py_version_manager.py_print("The given alias/username already exist!! Please use another name or delete the previous one")
             else:
                 self.add_json_to_file()
