@@ -29,41 +29,29 @@ def get_user_cred(name, x=0):
     
     file= system_file()
 
+    # try :
     # Opening JSON file
     f = open(file)
     
-    # returns JSON object as 
-    # a dictionary
+    # returns JSON object as a dictionary
     data = json.load(f)
 
     if(name=="all" and x==1):
-            return data.keys()
+                return data.keys()
     
     # Closing file
     f.close()
 
+    # except Exception as e:
+    #     ErrorLogs(traceback.format_list(traceback.extract_stack()), e, name).add_to_error_logs()
+    #     # if 'No such file or directory:' in str(e):
+    #     return None
+
+
     if(name in data):
         return[ data[name]['api_auth_token'], data[name]['api_key'] ]
+    elif x==2:
+        return None
     else:
         Py_version_manager.py_print("the given alias/credential doesn't exist")
         return None
-
-
-def check_user_cred(name):
-        
-    file= system_file()
-
-    # Opening JSON file
-    f = open(file)
-    
-    # returns JSON object as 
-    # a dictionary
-    data = json.load(f)
-    
-    # Closing file
-    f.close()
-
-    if(name in data):
-        return[ data[name]['api_auth_token'], data[name]['api_key'] ]
-    else:
-        return None
