@@ -81,5 +81,5 @@ class DBaaSClass:
                 Py_version_manager.py_print(
                          "To check the state of the database you can run e2e_cli dbaas list <alias> "
                 )
-            elif dbaas_delete_response_object["message"] == "Failure":
-                pass
+            elif dbaas_delete_response_object["message"] == "Aborted":
+                Py_version_manager.py_print(dbaas_delete_response_object["message"])
